@@ -133,7 +133,17 @@ typedef enum
   GSD_INPUT_SOURCES_SWITCHER_ALT_SHIFT_L,
   GSD_INPUT_SOURCES_SWITCHER_ALT_SHIFT_R,
   GSD_INPUT_SOURCES_SWITCHER_CTRL_SHIFT_L,
-  GSD_INPUT_SOURCES_SWITCHER_CTRL_SHIFT_R
+  GSD_INPUT_SOURCES_SWITCHER_CTRL_SHIFT_R,
+  GSD_INPUT_SOURCES_SWITCHER_SHIFT_L_SHIFT_R,
+  GSD_INPUT_SOURCES_SWITCHER_ALT_L_ALT_R,
+  GSD_INPUT_SOURCES_SWITCHER_CTRL_L_CTRL_R,
+  GSD_INPUT_SOURCES_SWITCHER_ALT_SHIFT,
+  GSD_INPUT_SOURCES_SWITCHER_CTRL_SHIFT,
+  GSD_INPUT_SOURCES_SWITCHER_ALT_CTRL,
+  GSD_INPUT_SOURCES_SWITCHER_CAPS,
+  GSD_INPUT_SOURCES_SWITCHER_SHIFT_CAPS,
+  GSD_INPUT_SOURCES_SWITCHER_ALT_CAPS,
+  GSD_INPUT_SOURCES_SWITCHER_CTRL_CAPS,
 } GsdInputSourcesSwitcher;
 
 #endif /* __gsd_enums_h__ */
