@@ -599,14 +599,14 @@ gcm_apply_create_icc_profile_for_edid (GsdColorManager *manager,
 
         cmsSetColorSpace (lcms_profile, cmsSigRgbData);
         cmsSetPCS (lcms_profile, cmsSigXYZData);
-        cmsSetHeaderRenderingIntent (lcms_profile,
-                                     INTENT_RELATIVE_COLORIMETRIC);
+        cmsSetHeaderRenderingIntent (lcms_profile, INTENT_PERCEPTUAL);
         cmsSetDeviceClass (lcms_profile, cmsSigDisplayClass);
 
         /* copyright */
         ret = _cmsWriteTagTextAscii (lcms_profile,
                                      cmsSigCopyrightTag,
-                                     "No copyright");
+                                     /* deliberately not translated */
+                                     "This profile is free of known copyright restrictions.");
         if (!ret) {
                 g_set_error_literal (error,
                                      GSD_COLOR_MANAGER_ERROR,
@@ -1433,6 +1433,22 @@ gcm_session_add_x11_output (GsdColorManager *manager, GnomeRROutput *output)
         g_hash_table_insert (device_props,
                              (gpointer) CD_DEVICE_METADATA_XRANDR_NAME,
                              (gpointer) gnome_rr_output_get_name (output));
+#if CD_CHECK_VERSION(0,1,25)
+        g_hash_table_insert (device_props,
+                             (gpointer) CD_DEVICE_METADATA_OUTPUT_PRIORITY,
+                             gnome_rr_output_get_is_primary (output) ?
+                             (gpointer) CD_DEVICE_METADATA_OUTPUT_PRIORITY_PRIMARY :
+                             (gpointer) CD_DEVICE_METADATA_OUTPUT_PRIORITY_SECONDARY);
+#endif
+#if CD_CHECK_VERSION(0,1,27)
+        /* set this so we can call the device a 'Laptop Screen' in the
+         * control center main panel */
+        if (gnome_rr_output_is_laptop (output)) {
+                g_hash_table_insert (device_props,
+                                     (gpointer) CD_DEVICE_PROPERTY_EMBEDDED,
+                                     NULL);
+        }
+#endif
         cd_client_create_device (priv->client,
                                  device_id,
                                  CD_OBJECT_SCOPE_TEMP,
